OC.L10N.register(
    "text",
    {
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "பதிவேற்றப்பட்ட கோப்பானது HTML  படிவத்தில் குறிப்பிடப்பட்டுள்ள MAX_FILE_SIZE  directive ஐ விட கூடியது",
    "No file was uploaded" : "எந்த கோப்பும் பதிவேற்றப்படவில்லை",
    "Missing a temporary folder" : "ஒரு தற்காலிகமான கோப்புறையை காணவில்லை",
    "Translate" : "Translate",
    "Keyboard shortcuts" : "விசைப்பலகை குறுக்குவழிகள்",
    "Link" : "Link",
    "Cancel" : "ரத்து செய்",
    "Upload" : "பதிவேற்றுக",
    "Edit" : "தொகுக்க",
    "Done" : "Done",
    "Details" : "விவரங்கள்",
    "Choose" : "தெரிவுசெய்க ",
    "Info" : "Info",
    "Warning" : "எச்சரிக்கை"
},
"nplurals=2; plural=(n != 1);");
